@@ -14,15 +14,19 @@ geom_spatraster_contour_filled <- function(mapping = NULL, data,
 
   # nocov start
   if (!requireNamespace("isoband", quietly = TRUE)) {
-    stop("Package `isoband` required. Run `install.packages('isoband')` first")
+    cli::cli_abort(paste(
+      "Package {.pkg isoband} required.",
+      "Run {.run install.packages('isoband')}"
+    ))
   }
   # nocov end
 
   if (!inherits(data, "SpatRaster")) {
-    stop(
-      "geom_spatraster_*() only works with SpatRaster objects. ",
-      "See ?terra::vect"
-    )
+    cli::cli_abort(paste(
+      "{.fun tidyterra::geom_spatraster_contour_filled} only works with",
+      "{.cls SpatRaster} objects, not {.cls {class(data)}}.",
+      "See {.help terra::vect}"
+    ))
   }
 
 
@@ -44,7 +48,7 @@ geom_spatraster_contour_filled <- function(mapping = NULL, data,
     namelayer <- vapply(mapping, rlang::as_label, character(1))["z"]
 
     if (!namelayer %in% names(data)) {
-      cli::cli_abort(paste("Layer", namelayer, "not found in data"))
+      cli::cli_abort(paste("Layer {.val {namelayer}} not found in {.arg data}"))
     }
 
     # Subset by layer
@@ -165,14 +169,19 @@ StatTerraSpatRasterContourFill <- ggplot2::ggproto(
     if (length(unique(data$PANEL)) != length(unique(data$lyr))) {
       nly <- length(unique(data$lyr))
       if (nly > 1) {
-        message(
-          "\nWarning message:\n",
-          "Plotting ", nly, " layers: ",
-          paste0("`", unique(data$lyr), "`", collapse = ", "),
-          ".(geom_spatraster_contour_filled).",
-          "\n- Use facet_wrap(~lyr) for faceting.",
-          "\n- Use aes(fill=<name_of_layer>) ",
-          "for displaying a single layer\n"
+        cli::cli_alert_warning(paste(
+          cli::style_bold("{.fun tidyterra::geom_spat_countour_filled}:"),
+          "Plotting {.field {nly}} overlapping layer{?s}:",
+          "{.val {unique(data$lyr)}}. Either:"
+        ))
+        cli::cli_bullets(
+          c(
+            " " = "Use {.code facet_wrap(~lyr)} for faceting or",
+            " " = paste(
+              "Use {.code aes(fill = <name_of_layer>)}",
+              "for displaying single layers"
+            )
+          )
         )
       }
     }
@@ -268,11 +277,11 @@ iso_to_polygon <- function(iso, group = 1, name_layer = NULL) {
   lengths <- vapply(iso, function(x) length(x$x), integer(1))
 
   if (all(lengths == 0)) {
-    warning(
-      "spatraster_contour(): Zero contours were generated for layer ",
-      name_layer,
-      call. = FALSE
-    )
+    cli::cli_warn(paste(
+      "In",
+      cli::style_bold("{.fun tidyterra::geom_spatraster_contour_filled}:"),
+      "Zero contours were generated"
+    ))
     return(NULL)
   }
 
