@@ -17,7 +17,8 @@
 #'
 #' @source Based on the `layer_spatial()` implementation on ggspatial package.
 #' Thanks to [Dewey Dunnington](https://github.com/paleolimbot) and
-#' [ggspatial contributors](https://github.com/paleolimbot/ggspatial/graphs/contributors).
+#' [ggspatial
+#' contributors](https://github.com/paleolimbot/ggspatial/graphs/contributors).
 #'
 #'
 #' @inheritParams geom_spatraster
@@ -30,7 +31,7 @@
 #'   See [grDevices::rgb()].
 #'
 #' @seealso [ggplot2::geom_raster()], [ggplot2::coord_sf()], [grDevices::rgb()].
-#'  You can get also RGB tiles from the {maptiles} package,
+#'  You can get also RGB tiles from the \CRANpkg{maptiles} package,
 #'  see [maptiles::get_tiles()].
 #'
 #' @section  terra equivalent:
@@ -94,10 +95,11 @@ geom_spatraster_rgb <- function(mapping = aes(),
                                 max_col_value = 255,
                                 ...) {
   if (!inherits(data, "SpatRaster")) {
-    stop(
-      "geom_spatraster() only works with SpatRaster objects. ",
-      "See ?terra::vect"
-    )
+    cli::cli_abort(paste(
+      "{.fun tidyterra::geom_spatraster_rgb} only works with",
+      "{.cls SpatRaster} objects, not {.cls {class(data)}}.",
+      "See {.help terra::vect}"
+    ))
   }
 
   layers_order <- as.integer(c(r, g, b))
@@ -111,8 +113,8 @@ geom_spatraster_rgb <- function(mapping = aes(),
     layers_order[3] %in% nlyrs_data
   )) {
     cli::cli_abort(paste(
-      "Incorrect number of layers on r,g,b. data has",
-      terra::nlyr(data), "layer(s)."
+      "Incorrect number of layers on {.arg {c('r','g','b')}}. data has",
+      "{terra::nlyr(data)}", "layer{?s}."
     ))
   }
 
